@@ -282,22 +282,22 @@ static void dump_solution()
 {
   guint i, j;
 
-  printf("Dumping solution\n");
+  g_warning("Dumping solution\n");
   for(i=0; i<(number_of_item_x+2); i++)
     {
       for(j=0; j<number_of_item_y; j++)
 	{
-	  printf("(%d,%d=%2d/%d) ",  position[i][j]->i,  position[i][j]->j, position[i][j]->color, 
+	  g_warning("(%d,%d=%2d/%d) ",  position[i][j]->i,  position[i][j]->j, position[i][j]->color, 
 		 position[i][j]->on_top);
 	}
-      printf("\n");
+      g_warning("\n");
     }
 
 }
 
 static void print_piece(PieceItem *piece)
 {
-  printf("Piece: (%d,%d=%2d/%d)\n",  piece->i,  piece->j, piece->color, piece->on_top);
+  g_warning("Piece: (%d,%d=%2d/%d)\n",  piece->i,  piece->j, piece->color, piece->on_top);
 }
 
 /* ==================================== */
@@ -311,6 +311,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
   guint used_colors[NUMBER_OF_COLOR];
   GnomeCanvasPathDef *path;
   guint w;
+  GdkPixbuf *pixmap = NULL;
       
   boardRootItem = GNOME_CANVAS_GROUP(
 				     gnome_canvas_item_new (gnome_canvas_root(gcomprisBoard->canvas),
@@ -319,6 +320,20 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 							    "y", (double) 0,
 							    NULL));
 
+  pixmap = gcompris_load_skin_pixmap("gcompris-shapelabel.png");
+  if(pixmap) {
+    gnome_canvas_item_new (boardRootItem,
+			   gnome_canvas_pixbuf_get_type (),
+			   "pixbuf", pixmap, 
+			   "x",	(double)BOARDWIDTH/2,
+			   "y",	(double)BOARDHEIGHT - 35,
+			   "width", (double) BOARDWIDTH - 20,
+			   "width_set", TRUE,
+			   "anchor", GTK_ANCHOR_CENTER,
+			   NULL);
+    gdk_pixbuf_unref(pixmap);
+  }
+
   gnome_canvas_item_new (boardRootItem,
 			 gnome_canvas_text_get_type (),
 			 "text", _("Reproduce in the empty area the same tower as the one on the right"),
@@ -337,7 +352,7 @@ static GnomeCanvasItem *hanoi_create_item(GnomeCanvasGroup *parent)
 			 "x", (double) BOARDWIDTH/2,
 			 "y", (double) BOARDHEIGHT - 50,
 			 "anchor", GTK_ANCHOR_NORTH,
-			 "fill_color", "white",
+			 "fill_color_rgba", gcompris_skin_color_text_button,
 			 "justification", GTK_JUSTIFY_CENTER,
 			 NULL);
 
