@@ -212,7 +212,7 @@ static void money_next_level()
   gchar		  *display_format;
 
   gcompris_set_background(gnome_canvas_root(gcomprisBoard->canvas),
-			  "money/money-bg.jpg");
+			  "money/money-bg.png");
 
   gcompris_bar_set_level(gcomprisBoard);
 
