@@ -11,6 +11,7 @@
 #include "py-mod-sound.h"
 #include "py-mod-timer.h"
 #include "py-mod-utils.h"
+#include "py-mod-anim.h"
 
 /* All functions provided by this python module
  * wraps a gcompris function. Each "py_*" function wraps the
@@ -476,25 +477,28 @@ py_gcompris_exit(PyObject* self, PyObject* args)
 /* Some functions and variables needed to get the file selector working */
 static PyObject* pyFileSelectorCallBackFunc = NULL;
 
-void pyFileSelectorCallBack(gchar* file){
+void pyFileSelectorCallBack(gchar* file, char* file_type){
   PyObject* args;
   PyObject* result;
   if(pyFileSelectorCallBackFunc==NULL) return;
 
   /* Build arguments */
-  args = PyTuple_New(1);
+  args  = PyTuple_New(2);
   PyTuple_SetItem(args, 0, Py_BuildValue("s", file));
+  PyTuple_SetItem(args, 1, Py_BuildValue("s", file_type));
   result = PyObject_CallObject(pyFileSelectorCallBackFunc, args);
   if(result==NULL){
     PyErr_Print();
   } else {
     Py_DECREF(result);
   }
+
 }
 
 
 /* void gcompris_file_selector_load(GcomprisBoard *gcomprisBoard,
                                     gchar *rootdir,
+				    gchar *file_types, (A Comma separated text explaining the different file types)
                                     FileSelectorCallBack fscb);
 */
 static PyObject*
@@ -503,12 +507,14 @@ py_gcompris_file_selector_load(PyObject* self, PyObject* args){
   GcomprisBoard* cGcomprisBoard;
   PyObject* pyCallback;
   gchar* rootdir;
+  gchar* file_types;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args,
-		       "OsO:gcompris_file_selector_load",
+		       "OssO:gcompris_file_selector_load",
 		       &pyGcomprisBoard,
 		       &rootdir,
+		       &file_types,
 		       &pyCallback))
     return NULL;
   if(!PyCallable_Check(pyCallback)) return NULL;
@@ -518,6 +524,7 @@ py_gcompris_file_selector_load(PyObject* self, PyObject* args){
   pyFileSelectorCallBackFunc = pyCallback;
   gcompris_file_selector_load(cGcomprisBoard,
                               rootdir,
+			      file_types,
                               pyFileSelectorCallBack);
 
   /* Create and return the result */
@@ -528,6 +535,7 @@ py_gcompris_file_selector_load(PyObject* self, PyObject* args){
 
 /* void gcompris_file_selector_save(GcomprisBoard *gcomprisBoard,
                                     gchar *rootdir,
+				    gchar *file_types, (A Comma separated text explaining the different file types)
                                     FileSelectorCallBack fscb);
 */
 static PyObject*
@@ -536,12 +544,14 @@ py_gcompris_file_selector_save(PyObject* self, PyObject* args){
   GcomprisBoard* cGcomprisBoard;
   PyObject* pyCallback;
   gchar* rootdir;
+  char* file_types;
 
   /* Parse arguments */
   if(!PyArg_ParseTuple(args,
-		       "OsO:gcompris_file_selector_save",
+		       "OssO:gcompris_file_selector_save",
 		       &pyGcomprisBoard,
 		       &rootdir,
+		       &file_types,
 		       &pyCallback))
     return NULL;
   if(!PyCallable_Check(pyCallback)) return NULL;
@@ -551,6 +561,7 @@ py_gcompris_file_selector_save(PyObject* self, PyObject* args){
   pyFileSelectorCallBackFunc = pyCallback;
   gcompris_file_selector_save(cGcomprisBoard,
                               rootdir,
+			      file_types,
                               pyFileSelectorCallBack);
 
   /* Create and return the result */
@@ -623,11 +634,12 @@ void python_gcompris_module_init(void)
   PyModule_AddStringConstant(gcomprisModule, "DEFAULT_SKIN", DEFAULT_SKIN);
 
   /* The GComprisBarFlags enum constants */
-  PyModule_AddIntConstant(gcomprisModule, "BAR_LEVEL",  GCOMPRIS_BAR_LEVEL);
-  PyModule_AddIntConstant(gcomprisModule, "BAR_OK",     GCOMPRIS_BAR_OK);
-  PyModule_AddIntConstant(gcomprisModule, "BAR_REPEAT", GCOMPRIS_BAR_REPEAT);
-  PyModule_AddIntConstant(gcomprisModule, "BAR_CONFIG", GCOMPRIS_BAR_CONFIG);
-  PyModule_AddIntConstant(gcomprisModule, "BAR_ABOUT",  GCOMPRIS_BAR_ABOUT);
+  PyModule_AddIntConstant(gcomprisModule, "BAR_LEVEL",       GCOMPRIS_BAR_LEVEL);
+  PyModule_AddIntConstant(gcomprisModule, "BAR_OK",          GCOMPRIS_BAR_OK);
+  PyModule_AddIntConstant(gcomprisModule, "BAR_REPEAT",      GCOMPRIS_BAR_REPEAT);
+  PyModule_AddIntConstant(gcomprisModule, "BAR_REPEAT_ICON", GCOMPRIS_BAR_REPEAT_ICON);
+  PyModule_AddIntConstant(gcomprisModule, "BAR_CONFIG",      GCOMPRIS_BAR_CONFIG);
+  PyModule_AddIntConstant(gcomprisModule, "BAR_ABOUT",       GCOMPRIS_BAR_ABOUT);
 
   /* Colors constants */
   PyModule_AddIntConstant(gcomprisModule, "COLOR_TITLE",       COLOR_TITLE);
@@ -684,6 +696,7 @@ void python_gcompris_module_init(void)
   python_gcompris_sound_module_init();
   python_gcompris_timer_module_init();
   python_gcompris_utils_module_init();
+  python_gcompris_anim_module_init();
 }
 
 /* Some usefull code parts ... */
