@@ -1,6 +1,6 @@
 /* gcompris - about.c
  *
- * Time-stamp: <2004/10/20 23:24:07 bruno>
+ * Time-stamp: <2005/02/13 11:59:55 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -64,7 +64,7 @@ void gcompris_about_start ()
   static gchar *content =
     N_("Author: Bruno Coudoin\n"
        "Contribution: Pascal Georges, Jose Jorge\n"
-       "Graphics: Renaud Blanchard\n"
+       "Graphics: Renaud Blanchard, Franck Doucet\n"
        "Intro Music: Djilali Sebihi\n"
        "Background Music: Rico Da Halvarez\n"
        );
@@ -249,7 +249,7 @@ void gcompris_about_start ()
   // License
   item = gnome_canvas_item_new (GNOME_CANVAS_GROUP(rootitem),
 				gnome_canvas_text_get_type (),
-				"text", _("This software is a GNU Package and is released under the GNU Public Licence"),
+				"text", _("This software is a GNU Package and is released under the GNU Public License"),
 				"font", gcompris_skin_font_content,
 				"x", (double)  BOARDWIDTH/2,
 				"y", (double)  y - 80,
