@@ -1,6 +1,6 @@
 /* gcompris - config.c
  *
- * Time-stamp: <2004/10/28 21:58:30 bruno>
+ * Time-stamp: <2005/03/11 21:46:17 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -64,6 +64,7 @@ static gchar *linguas[] = {
   "am_ET.UTF-8", 	N_("Amharic"),
   "ar_AE.UTF-8", 	N_("Arabic"),
   "az_AZ.UTF-8", 	N_("Azerbaijani Turkic"),
+  "bg_BG.UTF-8",	N_("Bulgarian"),
   "ca_ES.UTF-8",	N_("Catalan"),
   "cs_CZ.UTF-8",	N_("Czech"),
   "da_DK.UTF-8", 	N_("Danish"),
@@ -78,6 +79,7 @@ static gchar *linguas[] = {
   "ga_IE.UTF-8", 	N_("Irish (Gaelic)"),
   "he_IL.UTF-8",	N_("Hebrew"),
   "hi_IN.UTF-8",	N_("Indian (Hindi)"),
+  "gu_IN.UTF-8",	N_("Indian (Gujarati)"),
   "pa_IN.UTF-8",	N_("Indian (Punjabi)"),
   "hu_HU.UTF-8",	N_("Hungarian"),
   "hr_HR.UTF-8",	N_("Croatian"),
@@ -102,6 +104,7 @@ static gchar *linguas[] = {
   "sv_FI.UTF-8",	N_("Swedish"),
   "tr_TR.UTF-8",	N_("Turkish"),
   "wa_BE.UTF-8",	N_("Walloon"),
+  "zh_CN.UTF-8",	N_("Chinese (Simplified)"),
   NULL, NULL
 };
 
