@@ -1,6 +1,6 @@
 /* gcompris - gameutil.c
  *
- * Time-stamp: <2004/10/23 22:22:57 bruno>
+ * Time-stamp: <2005/02/16 22:11:28 bruno>
  *
  * Copyright (C) 2000 Bruno Coudoin
  *
@@ -75,7 +75,7 @@ gchar *gcompris_get_asset_file(gchar *dataset, gchar* categories,
     }
   else
     {
-      g_warning("Asset not found (dataset=%s category=%s mimetype=%s locale=%s file=%s)\n", 
+      g_warning("Asset not found (dataset='%s' category='%s' mimetype='%s' locale='%s' file='%s')\n", 
 		dataset, categories, mimetype, gcompris_get_locale(), file);
     }
   assetml_free_assetlist(gl_result);
@@ -118,8 +118,12 @@ GdkPixbuf *gcompris_load_pixmap(char *pixmapfile)
   gchar *filename;
   GdkPixbuf *pixmap;
 
+
   /* Search it on the file system */
-  filename = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR, pixmapfile);
+  if (!g_path_is_absolute (pixmapfile))
+    filename = g_strdup_printf("%s/%s", PACKAGE_DATA_DIR, pixmapfile);
+  else 
+    filename = pixmapfile;
 
   if (!g_file_test ((filename), G_FILE_TEST_EXISTS)) {
     char *str;
@@ -139,8 +143,6 @@ GdkPixbuf *gcompris_load_pixmap(char *pixmapfile)
   if(!pixmap)
     g_warning("Loading image returned a null pointer");
 
-  g_free (filename);
-
   return(pixmap);
 }
 
@@ -599,7 +601,7 @@ GList *gcompris_get_menulist(gchar *section)
   for(list = boards_list; list != NULL; list = list->next) {
     GcomprisBoard *board = list->data;
 
-    if(board->section 
+    if(board && board->section 
        && strlen(section)<=strlen(board->section)
        && strcmp (section, board->section) != 0) {
 
@@ -727,11 +729,50 @@ void item_rotate(GnomeCanvasItem *item, double angle) {
    rotation is clockwise if angle > 0 */
 void item_rotate_relative(GnomeCanvasItem *item, double angle) {
   double x1, x2, y1, y2;
+  double tx1, tx2, ty1, ty2;
   double cx, cy;
   double t;
   double r[6];
 
-  gnome_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
+  //  gnome_canvas_item_get_bounds( item, &x1, &y1, &x2, &y2 );
+  /* WARNING: Do not use gnome_canvas_item_get_bounds which gives unpredictable results */
+  if(GNOME_IS_CANVAS_LINE(item)) {
+    GnomeCanvasPoints	*points;
+    gtk_object_get (GTK_OBJECT (item), "points", &points, NULL);
+    x1 = points->coords[0];
+    y1 = points->coords[1];
+    x2 = points->coords[2];
+    y2 = points->coords[3];
+  } else if(GNOME_IS_CANVAS_PIXBUF(item)){
+    gtk_object_get (GTK_OBJECT (item), "x", &x1, NULL);
+    gtk_object_get (GTK_OBJECT (item), "y", &y1, NULL);
+    gtk_object_get (GTK_OBJECT (item), "width",  &x2, NULL);
+    gtk_object_get (GTK_OBJECT (item), "height", &y2, NULL);
+    x2 += x1;
+    y2 += y1;
+  } else if(GNOME_IS_CANVAS_GROUP(item)){
+    gtk_object_get (GTK_OBJECT (item), "x", &x1, NULL);
+    gtk_object_get (GTK_OBJECT (item), "y", &y1, NULL);
+    x2 = x1;
+    y2 = y1;
+  } else {
+    gtk_object_get (GTK_OBJECT (item), "x1", &x1, NULL);
+    gtk_object_get (GTK_OBJECT (item), "y1", &y1, NULL);
+    gtk_object_get (GTK_OBJECT (item), "x2", &x2, NULL);
+    gtk_object_get (GTK_OBJECT (item), "y2", &y2, NULL);
+  }
+
+  tx1 = x1;
+  ty1 = y1;
+  tx2 = x2;
+  ty2 = y2;
+
+  x1 = MIN(tx1,tx2);
+  y1 = MIN(ty1,ty2);
+  x2 = MAX(tx1,tx2);
+  y2 = MAX(ty1,ty2);
+    
+
   cx = (x2+x1)/2;
   cy = (y2+y1)/2;
 
@@ -799,7 +840,7 @@ void gcompris_dialog_close() {
   if(rootDialogItem) {
     /* WORKAROUND: There is a bug in the richtex item and we need to remove it first */
     while (g_idle_remove_by_data (itemDialogText));
-    gtk_object_destroy (itemDialogText);
+    gtk_object_destroy (GTK_OBJECT(itemDialogText));
     itemDialogText = NULL;
 
     gtk_object_destroy(GTK_OBJECT(rootDialogItem));
