@@ -35,6 +35,14 @@
 // returns a random integer in range [A,B]
 #define RAND(A,B) (A + (int)((float)(B-A+1)*rand()/(RAND_MAX+1.0)))
 
+#ifndef MAX
+#define MAX(a,b) (((a) > (b)) ? (a) : (b))
+#endif
+
+#ifndef MIN
+#define MIN(a,b) (((a) < (b)) ? (a) : (b))
+#endif
+
 gchar 		*g_utf8_strndup(gchar*,gint);
 
 GdkPixbuf	*gcompris_load_pixmap(char *pixmapfile);
@@ -46,6 +54,7 @@ GcomprisBoard	*gcompris_read_xml_file(GcomprisBoard *gcomprisBoard, char *fname)
 GcomprisBoard   *gcompris_get_board_from_section(gchar *section);
 GList		*gcompris_get_menulist(gchar *section);
 void		 gcompris_load_menus();
+void		 gcompris_load_mime_types();
 
 gchar		*convertUTF8Toisolat1(gchar * text);
 void		 item_absolute_move(GnomeCanvasItem *item, int x, int y);
