@@ -1,6 +1,6 @@
 /* gcompris - gcompris.c
  *
- * Time-stamp: <2004/10/20 23:25:19 bruno>
+ * Time-stamp: <2005/03/31 23:34:02 bruno>
  *
  * Copyright (C) 2000-2003 Bruno Coudoin
  *
@@ -32,6 +32,14 @@
 
 #include "cursor.h"
 
+/* For XRANDR Support */
+#ifdef XRANDR
+#include <gdk/gdkx.h>
+#include <X11/Xlib.h>
+#include <X11/extensions/Xrandr.h>
+#include <X11/extensions/Xrender.h>
+#endif
+
 #if defined _WIN32 || defined __WIN32__
 # undef WIN32   /* avoid warning on mingw32 */
 # define WIN32
@@ -76,6 +84,7 @@ static int popt_version		  = FALSE;
 static int popt_aalias		  = FALSE;
 static int popt_difficulty_filter = FALSE;
 static int popt_debug		  = FALSE;
+static int popt_noxrandr	  = FALSE;
 
 static struct poptOption options[] = {
   {"fullscreen", 'f', POPT_ARG_NONE, &popt_fullscreen, 0,
@@ -96,6 +105,8 @@ static struct poptOption options[] = {
    N_("Print the version of " PACKAGE), NULL},
   {"antialiased", 'a', POPT_ARG_NONE, &popt_aalias, 0,
    N_("Use the antialiased canvas (slower)."), NULL},
+  {"noxrandr", 'x', POPT_ARG_NONE, &popt_noxrandr, 0,
+   N_("Disable XRANDR (No screen resolution change)."), NULL},
 #ifndef WIN32
   POPT_AUTOHELP
 #endif
@@ -110,6 +121,29 @@ static struct poptOption options[] = {
   }
 };
 
+/* XRandr Stuff */
+#ifdef XRANDR
+typedef struct 
+{
+  gboolean                xr_lock_updates;
+
+  XRRScreenConfiguration *xr_screen_conf;
+
+  XRRScreenSize          *xr_sizes;
+  int                     xr_nsize;
+  SizeID	          xr_current_size;
+
+  Rotation                xr_rotations;
+  Rotation                xr_current_rotation;
+
+} XRANDRData; 
+
+static SizeID xr_previous_size;
+static XRANDRData   *xrandr;
+
+static void xrandr_get_config ( XRANDRData *data );
+gboolean xrandr_set_config( XRANDRData  *grandr );
+#endif
 
 /****************************************************************************/
 
@@ -168,8 +202,17 @@ board_widget_key_press_callback (GtkWidget   *widget,
       return TRUE;
     case GDK_KP_Enter:
     case GDK_Return:
-      if (get_current_board_plugin()!=NULL && get_current_board_plugin()->ok)
+      /* If the board needs to receive key pressed */
+      /* NOTE: If a board receives key press, it must bind the ENTER Keys to OK
+       *       whenever possible
+       */
+      if (get_current_board_plugin()!=NULL && get_current_board_plugin()->key_press)
 	{
+	  return(get_current_board_plugin()->key_press (event->keyval));
+	} 
+      else if (get_current_board_plugin()!=NULL && get_current_board_plugin()->ok)
+	{
+	  /* Else we send the OK signal. */
 	  get_current_board_plugin()->ok ();
 	}
       return TRUE;
@@ -184,6 +227,7 @@ board_widget_key_press_callback (GtkWidget   *widget,
 	}
     }
 
+  /* Event not handled; try parent item */
   return FALSE;
 };
 
@@ -230,12 +274,41 @@ GnomeCanvasItem *gcompris_set_background(GnomeCanvasGroup *parent, gchar *file)
 static void init_background()
 {
   double xratio, yratio, max;
+  gint screen_height, screen_width;
   GtkWidget *vbox;
+  int i;
 
-  yratio=gdk_screen_height()/(float)(BOARDHEIGHT+BARHEIGHT);
-  xratio=gdk_screen_width()/(float)BOARDWIDTH;
-    g_message("The gdk_screen_width()=%f gdk_screen_height()=%f\n",
-  	 (double)gdk_screen_width(), (double)gdk_screen_height());
+#ifdef XRANDR
+  /* Search the 800x600 Resolution */
+  printf("properties->noxrandr=%d\n", properties->noxrandr);
+  if(properties->fullscreen && !properties->noxrandr) {
+
+    xrandr = g_new0 (XRANDRData, 1);
+    xrandr_get_config ( xrandr );
+    xr_previous_size = (SizeID)xrandr->xr_current_size;
+
+    for (i = 0; i < xrandr->xr_nsize; i++) {
+      if(xrandr->xr_sizes[i].width == BOARDWIDTH, xrandr->xr_sizes[i].height == BOARDHEIGHT+BARHEIGHT) {
+	xrandr->xr_current_size = (SizeID)i;
+	xrandr_set_config( xrandr );
+	break;
+      }
+    }
+    screen_height = xrandr->xr_sizes[xrandr->xr_current_size].height;
+    screen_width  = xrandr->xr_sizes[xrandr->xr_current_size].width;
+  } else {
+  screen_height = gdk_screen_height();
+  screen_width  = gdk_screen_width();
+  }
+#else
+  screen_height = gdk_screen_height();
+  screen_width  = gdk_screen_width();
+#endif
+
+  yratio=screen_height/(float)(BOARDHEIGHT+BARHEIGHT);
+  xratio=screen_width/(float)BOARDWIDTH;
+    g_message("The screen_width=%f screen_height=%f\n",
+  	 (double)screen_width, (double)screen_height);
     g_message("The xratio=%f yratio=%f\n", xratio, yratio);
 
   yratio=xratio=MIN(xratio, yratio);
@@ -265,23 +338,22 @@ static void init_background()
       /* WARNING : I add 30 here for windows. don't know why it's needed. Doesn't hurt the Linux version */
       gnome_canvas_set_scroll_region (canvas_bg,
 				      0, 0,
-				      gdk_screen_width(),
-				      gdk_screen_height() + 30);
+				      screen_width,
+				      screen_height + 30);
       
-      gtk_widget_set_usize (GTK_WIDGET(canvas_bg), gdk_screen_width(), gdk_screen_height());
+      gtk_widget_set_usize (GTK_WIDGET(canvas_bg), screen_width, screen_height);
       
       /* Create a black box for the background */
       gnome_canvas_item_new (gnome_canvas_root(canvas_bg),
 			     gnome_canvas_rect_get_type (),
 			     "x1", (double) 0,
 			     "y1", (double) 0,
-			     "x2", (double) gdk_screen_width(),
-			     "y2", (double) gdk_screen_height() + 30,
+			     "x2", (double) screen_width,
+			     "y2", (double) screen_height + 30,
 			     "fill_color", "black",
 			     "outline_color", "black",
 			     "width_units", (double)0,
 			     NULL);
-      
     }
 
   /* Create a vertical box in which I put first the play board area, then the button bar */
@@ -301,9 +373,9 @@ static void init_background()
       gnome_canvas_item_new (gnome_canvas_root(canvas_bg),
 			     gnome_canvas_widget_get_type (),
 			     "widget", vbox, 
-			     "x", (double) (gdk_screen_width()-
+			     "x", (double) (screen_width-
 					    BOARDWIDTH*xratio)/2,
-			     "y", (double) (gdk_screen_height()-
+			     "y", (double) (screen_height-
 					    BOARDHEIGHT*xratio-BARHEIGHT*xratio)/2,
 			     "width",  (double)BOARDWIDTH*xratio,
 			     "height", (double)BOARDHEIGHT*xratio+BARHEIGHT*xratio,
@@ -397,8 +469,8 @@ void gcompris_set_cursor(guint gdk_cursor_type)
 
 static void setup_window ()
 {
-  GdkPixbuf *gcompris_icon_pixbuf;
-  GError *error = NULL;
+  GdkPixbuf    *gcompris_icon_pixbuf;
+  GError       *error = NULL;
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
@@ -435,9 +507,6 @@ static void setup_window ()
 
   gtk_signal_connect (GTK_OBJECT (window), "delete_event",
 		      GTK_SIGNAL_FUNC (quit_cb), NULL);
-  gtk_signal_connect (GTK_OBJECT (window), "key_press_event",
-		      GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
-
 
   /* For non anti alias canvas */
   gtk_widget_push_visual (gdk_rgb_get_visual ());
@@ -467,6 +536,15 @@ static void setup_window ()
       canvas_bg  = GNOME_CANVAS(gnome_canvas_new ());
     }
 
+  gtk_signal_connect_after (GTK_OBJECT (window), "key_press_event",
+			    GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
+  gtk_signal_connect_after (GTK_OBJECT (canvas), "key_press_event",
+			    GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
+  gtk_signal_connect_after (GTK_OBJECT (canvas_bar), "key_press_event",
+			    GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
+  gtk_signal_connect_after (GTK_OBJECT (canvas_bg), "key_press_event",
+			    GTK_SIGNAL_FUNC (board_widget_key_press_callback), 0);
+
   if(properties->fullscreen)
     gtk_container_add (GTK_CONTAINER (window), GTK_WIDGET(canvas_bg));
 
@@ -489,6 +567,9 @@ static void setup_window ()
   /* Load all the menu once */
   gcompris_load_menus();
 
+  /* Load the mime type */
+  gcompris_load_mime_types();
+
   /* Get and Run the root menu */
   gcomprisBoardMenu = gcompris_get_board_from_section("/");
   if(!board_check_file(gcomprisBoardMenu)) {
@@ -505,18 +586,6 @@ static void setup_window ()
 
 #ifdef WIN32
   {
-    time_t	 ctime;
-    gchar	*prog;
-    struct stat  buf;
-
-    ctime = time(NULL);
-    prog = g_find_program_in_path("gcompris");
-    if(stat(prog, &buf)==0) {
-      if(difftime(ctime, buf.st_mtime)<2592000) {
-	grace_period = 1;
-	return;
-      }
-    }
     if(strncmp(properties->key, "thanks_for_your_help", 20)!=0) {
       board_pause();
       gcompris_dialog(_("GCompris is free software released under the GPL License. In order to support the development, the Windows version provides only 12 of the 45 activities. You can get the full version for a small fee at\nhttp://gcompris.net\nThe Linux version does not have this restriction. Note that gcompris is being developped to free schools from monopolistic software vendors. If you also believe that we should teach freedom to kids, please consider using GNU/Linux. Get more information on\nhttp://www.fsf.org/philosophy"), NULL);
@@ -538,7 +607,19 @@ void gcompris_end_board()
 void gcompris_exit()
 {
   board_stop();
+
+#ifdef XRANDR
+  /* Set back the original screen size */
+  if(properties->fullscreen) {
+    xrandr_get_config ( xrandr );	/* Need to refresh our config or xrandr api will reject us */
+    xrandr->xr_current_size = (SizeID)xr_previous_size;
+    xrandr_set_config( xrandr );
+  }
+#endif
+
   gtk_main_quit ();
+
+
 }
 
 static void quit_cb (GtkWidget *widget, gpointer data)
@@ -656,6 +737,47 @@ void gcompris_log_handler (const gchar *log_domain,
     g_printerr ("%s: %s\n\n", "gcompris", message);
 }
 
+#ifdef XRANDR
+/*
+ * XRANDR STUFF
+ * ------------
+ */
+static void
+xrandr_get_config ( XRANDRData *data )
+{
+  data->xr_screen_conf = XRRGetScreenInfo (GDK_DISPLAY(), GDK_ROOT_WINDOW());
+  
+  data->xr_current_size = XRRConfigCurrentConfiguration (data->xr_screen_conf, 
+							 &data->xr_current_rotation);
+
+  data->xr_sizes = XRRConfigSizes(data->xr_screen_conf, &data->xr_nsize);
+  
+  data->xr_rotations = XRRConfigRotations(data->xr_screen_conf,
+					  &data->xr_current_rotation);
+}
+
+gboolean
+xrandr_set_config( XRANDRData  *data )
+{
+  Status  status = RRSetConfigFailed;
+
+  if (data->xr_lock_updates) return FALSE;
+  
+  status = XRRSetScreenConfig (GDK_DISPLAY(), 
+			       data->xr_screen_conf, 
+			       GDK_ROOT_WINDOW(), 
+			       data->xr_current_size, 
+			       data->xr_current_rotation, 
+			       CurrentTime);
+
+  if(status) {
+    printf("ERROR: Failed to set back the original resolution XRRSetScreenConfig returned status = %d\n", (int)status);
+  }
+  return TRUE;
+
+}
+#endif
+
 /*****************************************
  * Main
  *
@@ -730,6 +852,11 @@ gcompris_init (int argc, char *argv[])
       properties->fullscreen = TRUE;
     }
 
+  if (popt_noxrandr)
+    {
+      properties->noxrandr = TRUE;
+    }
+
   if (popt_window)
     {
       properties->fullscreen = FALSE;
