@@ -1,6 +1,6 @@
 /* gcompris - gcompris.h
  *
- * Time-stamp: <2004/07/15 22:15:33 bcoudoin>
+ * Time-stamp: <2005/01/07 00:32:49 bruno>
  *
  * Copyright (C) 2000,2001,2002 Bruno Coudoin
  *
@@ -47,6 +47,7 @@
 #include "timer.h"
 #include "score.h"
 #include "skin.h"
+#include "anim.h"
 
 #ifdef DMALLOC
 #include "dmalloc.h"
@@ -60,7 +61,10 @@
 
 #define _(String) gettext (String)
 #define gettext_noop(String) String
+
+#ifndef N_
 #define N_(String) gettext_noop (String)
+#endif
 
 /*****************************************************************************/
 /* Method usefull for boards provided by gcompris */
@@ -117,12 +121,14 @@ void		 gcompris_images_selector_start (GcomprisBoard *gcomprisBoard,
 						 ImageSelectorCallBack imscb);
 void		 gcompris_images_selector_stop (void);
 
-typedef void     (*FileSelectorCallBack)     (gchar* file);
+typedef void     (*FileSelectorCallBack)     (gchar *file, gchar *file_type); /* file_type is one string from file_types in the save */
 void		 gcompris_file_selector_load (GcomprisBoard *gcomprisBoard, 
-					      gchar *rootdir, 
+					      gchar *rootdir,
+					      gchar *file_types, /* A Comma separated text explaining the different file types */
 					      FileSelectorCallBack fscb);
 void		 gcompris_file_selector_save (GcomprisBoard *gcomprisBoard,
 					      gchar *rootdir,
+					      gchar *file_types, /* A Comma separated text explaining the different file types */
 					      FileSelectorCallBack fscb);
 void		 gcompris_file_selector_stop (void);
 
